==> open-xchange-usm_7.4.0.orig.tar.bz2: open-xchange-usm-7.4.0/com.openexchange.usm.api/src/com/openexchange/usm/api/exceptions/FolderNotFoundException.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.api.exceptions;

import org.json.JSONObject;

/**
 * Special Exception that is thrown by the USM if a Folder can not be located
 * by its folderid, either in the cache (if cached data is available) or directly
 * on the OX server.
 * 
 * @author afe
 *
 */
public class FolderNotFoundException extends USMException {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;

	public FolderNotFoundException(int errorCode, String message) {
		super(errorCode, message);
	}

	public FolderNotFoundException(int errorCode, String message, Throwable cause) {
		super(errorCode, message, cause);
	}

	@Override
	public JSONObject getErrorDetailsForJSONResponse() {
		return null;
	}

	@Override
	public JSONObject getOxErrorForJSONResponse() {
		return null;
	}
}

==> open-xchange-usm_7.6.0.orig.tar.bz2: open-xchange-usm-7.6.0/com.openexchange.usm.api/src/com/openexchange/usm/api/exceptions/FolderNotFoundException.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the Open-Xchange, Inc. group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2004-2010 Open-Xchange, Inc.
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */
package com.openexchange.usm.api.exceptions;

import org.json.JSONObject;

/**
 * Special Exception that is thrown by the USM if a Folder can not be located
 * by its folderid, either in the cache (if cached data is available) or directly
 * on the OX server.
 * 
 * @author afe
 *
 */
public class FolderNotFoundException extends USMException {
	/**
	 * 
	 */
	private static final long serialVersionUID = 1L;
	
	private final JSONObject _jsonError;

	public FolderNotFoundException(int errorCode, String message) {
		super(errorCode, message);
		_jsonError = null;
	}

	public FolderNotFoundException(int errorCode, String message, Throwable cause) {
		super(errorCode, message, cause);
		_jsonError = null;
	}
	
	public FolderNotFoundException(int errorCode, String message, JSONObject errorDetails) {
        super(errorCode, message);
        _jsonError = errorDetails;
    }

	@Override
	public JSONObject getErrorDetailsForJSONResponse() {
		return null;
	}

	@Override
	public JSONObject getOxErrorForJSONResponse() {
		return _jsonError;
	}
	
	@Override
	public String toString() {
	    StringBuilder sb = new StringBuilder(super.toString());
        if (_jsonError != null)
            sb.append(", json-error=").append(_jsonError);
        return sb.toString();
	}
	
	@Override
	public String getMessage() {
	    StringBuilder sb = new StringBuilder(super.getMessage());
        if (_jsonError != null)
            sb.append(", json-error=").append(_jsonError);
        return sb.toString();
	}
}
